@@ -45,7 +45,7 @@ def responce(r):
 	503: 'Сервер перегружен',
 	504: 'Шлюз не отвечает слишком долго'
 	}
-	try: return answer[r.status_code]
+	try: return answer.get(r.status_code, r.status_code)
 	except KeyError: return r.status_code
 	except object as err: return err
 
@@ -89,6 +89,9 @@ class monitoring2:
 	user_by_id(id) - Поиск пользователя по id
 	change_tenant(org_id, tenant_id) - Смена тенанта организации по id
 	check_promo(promo_id) - Проверка КА по id или полному коду
+	change_agent_code(*, kkmId, serviceId, agentCode) - Получение кодов агента по id ККТ (заполняется переменная self.agentCodes)
+	get_agent_code(kkm_id) - Получение кодов агента по id ККТ
+	add_capability_to_org(org_id, capability) - Добавление эксклюзивного права организации по id
 	'''
 
 	def __init__(self, login, password, url = 'http://taxplayer.ensyco.local', crpt = False, echo = True):
@@ -97,6 +100,7 @@ class monitoring2:
 		self.__mon_password = password
 		if crpt: self.__mon_password = encrypt(pas = password)
 		self.log = []
+		self.agentCodes = []
 		self.echo = echo
 		self.ms = rq.Session()
 		self.login()
@@ -110,6 +114,7 @@ class monitoring2:
 		del self.mon_login
 		del self.__mon_password
 		del self.ms
+		del self.agentCodes
 
 	def logger(self, text):
 		'''
@@ -282,6 +287,32 @@ class monitoring2:
 		self.r = self.ms.get('{}/api/promo/{}'.format(self.URL, promo_id))
 		return self.logger('Проверяем КА {}...'.format(promo_id))
 
+	def get_agent_code(self, kkm_id):
+		'''
+		Получение кодов агента по id ККТ
+		'''
+		if len(rnm)!=16: return
+		kkm_id=self.seek_kkm(rnm)['id']
+		self.r=self.seek_kkm_by_id(kkm_id)
+		self.agentCodes=[{'kkm_id':kkm_id, 'agentCode':x.get('agentCode', '0000000000'), 'serviceId': x['id']} for x in self.r['kkmModel']['serviceLog']]
+
+	def change_agent_code(self, *, kkmId, serviceId, agentCode):
+		'''
+		Изменение кода агена по ККТ id и serviceId
+		'''
+		json={"kkmId": int(kkmId),"activationStartTime":"","updates":[{"serviceId":int(serviceId),"agentCode":str(agentCode)}, ]}
+		self.r = self.ms.post('{0}/api/kkms/service-log/update'.format(self.URL), json=json)
+		return self.logger('Меняем код агента для ККТ id {0} на {1} ...'.format(kkmId, agentCode))
+
+	def add_capability_to_org(self, org_id, capability):
+		'''
+		Добавление эксклюзивного права организации по id
+		'''
+		url = f'{self.URL}/api/organisations/add-capability'
+		json = {"orgId":int(org_id),"capability":capability}
+		self.r = self.ms.post(url, json=json)
+		return self.logger('Добавляем право для организации id {0} ...'.format(org_id))
+
 class prodRf:
 
 	help = '''
